﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace LevelEditor
{
    class DataPaths
    {
        public static void Load(String fileName)
        {
            System.Xml.XmlReaderSettings xmlSettings = new System.Xml.XmlReaderSettings();
            xmlSettings.IgnoreComments = true;
            xmlSettings.IgnoreWhitespace = true;

            try
            {
                System.Xml.XmlReader reader = System.Xml.XmlReader.Create(fileName, xmlSettings);
                System.Xml.XmlDocument doc = new System.Xml.XmlDocument();
                doc.Load(reader);

                if (doc.FirstChild.Name != "DataPaths")
                {
                    MainWindow.ConsoleWriteLine("The file '" + fileName + "' is missing the top level <DataPaths> ... </DataPaths> nodes."); 
                    return;
                }

                System.Xml.XmlNode levelNodes = doc.FirstChild;
                foreach (System.Xml.XmlNode n in levelNodes)
                {
                    if (!System.IO.Directory.Exists(n.InnerText))
                    {
                        MainWindow.ConsoleWriteLine("WARNING: The directory '" + n.InnerText 
                            + "' for the '" + n.Name + "' data path does not exit.");
                    }

                    Paths[n.Name] = System.IO.Path.GetFullPath(n.InnerText);
                }

                MainWindow.ConsoleWriteLine("DataPaths Loaded.");
            }
            catch (System.IO.FileNotFoundException e)
            {
                MainWindow.ConsoleWriteLine("File '" + e.Message + "' could not be found.");
                MainWindow.ConsoleWriteLine("ERROR: DataPaths Were NOT Loaded.");
            }
            catch (System.Xml.XmlException e)
            {
                MainWindow.ConsoleWriteLine("XML error in '" + System.IO.Path.GetFileName(fileName) + "' -> " + e.Message);
                MainWindow.ConsoleWriteLine("ERROR: DataPaths Were NOT Loaded.");
            }
        }

        public class PathData
        {
            private Dictionary<String, String> pathMap = new Dictionary<String, String>();

            public String this[String name]
            {
                get
                {
                    String val;
                    if (pathMap.TryGetValue(name.ToLower(), out val))
                        return val;
                    return null;
                }

                set
                {
                    pathMap[name.ToLower()] = value;
                }
            }
        };

        static DataPaths()
        {
            Paths = new PathData();
        }

        public static PathData Paths { get; private set; }
    }
}
