﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace LevelEditor
{
    public partial class DataSelectionDialog : Form
    {
        public DataSelectionDialog()
        {
            InitializeComponent();
        }

        #region Initialization Stuff

        public void SetDataPath(String loc, List<String> supportedExtensions)
        {
            TreeView.SetDataPath(loc, supportedExtensions);
        }

        #endregion

        public void RefreshTreeView()
        {
            TreeView.RefreshTreeView();
        }

        // Sets the current selection on the list view
        public void SetSelection(String path)
        {
            TreeView.SetSelection(path);
        }

        // returns true if the current selection has changed.
        protected bool SetSelection()
        {
            // makes sure the node is a leaf node
            if (TreeView.SelectedNode.Nodes.Count > 0)
            {
                return false;
            }

            // builds the path from the selected node to the root (root will not be included)
            List<String> pathFromRoot = new List<String>();
            TreeNode curr = TreeView.SelectedNode.Parent;
            while (curr != null && curr.Parent != null)
            {
                pathFromRoot.Add(curr.Text);
                curr = curr.Parent;
            }

            String path = "";
            for (int i = pathFromRoot.Count - 1; i >= 0; i--)
            {
                path += pathFromRoot[i] + Path.DirectorySeparatorChar;
            }

            selectionName = TreeView.SelectedNode.Text;
            selectionDir = path + selectionName;
            selectionFullPath = Path.Combine(TreeView.path, selectionDir);
            return true;
        }

        protected virtual void SetPreview() { }

        protected virtual void ResetPreview() { }

        #region Events

        private void TreeView_AfterSelect(object sender, TreeViewEventArgs e)
        {
            if (SetSelection())
            {
                SetPreview();
            }
        }

        private void RefreshButton_Click(object sender, EventArgs e)
        {
            RefreshTreeView();
            ResetPreview();
        }

        #endregion

        public String selectionName { get; private set; }
        public String selectionDir { get; private set; }
        public String selectionFullPath { get; private set; }
    }
}
