﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace LevelEditor
{
    public partial class DataSelectionTreeView : TreeView
    {
        public DataSelectionTreeView()
        {
            InitializeComponent();
        }

        public void SetDataPath(String loc, List<String> extensions)
        {
            if (!Directory.Exists(loc))
            {
                throw new DirectoryNotFoundException();
            }

            path = loc;
            directory = Path.GetFileName(path);
            supportedExtensions = extensions;

            RefreshTreeView();
        }

        public void RefreshTreeView()
        {
            Nodes.Clear();

            TreeNode newNode = Nodes.Add(directory);
            AddDirectory(new DirectoryInfo(path), newNode);

            if (newNode.Nodes.Count == 0)
                Nodes.Remove(newNode);
        }

        // Sets the current selection on the list view
        public void SetSelection(String path)
        {
            // There should only be one root node.
            if(Nodes.Count != 1)
                return;

            String[] deliminators = { PathSeparator };
            String[] nodeNames = path.Split(deliminators, StringSplitOptions.RemoveEmptyEntries);

            TreeNode n = null;
            TreeNodeCollection currCol = Nodes[0].Nodes;
            foreach (String s in nodeNames)
            {
                n = null;
                for (int i = 0; i < currCol.Count; i++)
                {
                    if (currCol[i].Text == s)
                    {
                        n = currCol[i];
                        break;
                    }
                }

                if (n == null)
                    return;

                currCol = n.Nodes;
            }

            SelectedNode = n;
        }

        private void AddDirectory(DirectoryInfo dir, TreeNode n)
        {
            foreach (DirectoryInfo d in dir.GetDirectories())
            {
                if (d.Name[0] != '.') // Ignores special directories specifically subversion .svn folders
                {
                    TreeNode newNode = n.Nodes.Add(d.Name);
                    AddDirectory(d, newNode);

                    if (newNode.Nodes.Count == 0)
                        n.Nodes.Remove(newNode);
                }
            }

            foreach (FileInfo f in dir.GetFiles())
            {
                String ext = Path.GetExtension(f.Name);
                if(supportedExtensions.Contains(ext))
                    n.Nodes.Add(f.Name);
            }
        }

        public String path;
        public String directory;
        List<String> supportedExtensions;
    }
}
