﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Text;

namespace LevelEditor
{
    public partial class FontSelectionDialog : DataSelectionDialog
    {
        public FontSelectionDialog()
        {
            InitializeComponent();

            format.Alignment = StringAlignment.Center;
            SizeNumericUpDown.Value = fontSize;
        }

        protected override void SetPreview()
        {
            fonts = new PrivateFontCollection();
            fonts.AddFontFile(selectionFullPath);

            font = new Font(fonts.Families[0], fontSize);

            fontPanel.Refresh();
        }

        protected override void ResetPreview()
        {
            font = null;
            fonts = null;
        }

        private void fontPanel_Paint(object sender, PaintEventArgs e)
        {
            if(font != null)
            {
                Graphics gfx = fontPanel.CreateGraphics();

                gfx.Clear(Color.White);

                Rectangle r = new Rectangle();
                r.X = 0; 
                r.Y = 0;
                r.Width = fontPanel.Width;
                r.Height = fontPanel.Height;

                gfx.DrawString(PreviewText, font, Brushes.Black, r, format);
            }
        }

        private void SizeNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            fontSize = (int)SizeNumericUpDown.Value;

            if (font != null)
            {
                font = new Font(fonts.Families[0], fontSize);
                fontPanel.Refresh();
            }
        }

        private System.Drawing.Font font = null;
        private PrivateFontCollection fonts = null;

        public int FontSize
        {
            get { return fontSize; }
            set { SizeNumericUpDown.Value = value; fontSize = value; }
        }

        private int fontSize = 12;
        private StringFormat format = new StringFormat();

        private static String PreviewText = "ABCDEFGHIJKLMNOPQRSTUVWXYZ\n\n"
            + "abcdefghijklmnopqrstuvwxyz\n\n"
            + "0123456789\n\n"
            + "!@#$%^&*()_-=+\\/|[]{}<>,.;:`~'\"";
    }
}
