﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace LevelEditor
{
    class Grid
    {
        public int X = 0; // top left corner of the grid
        public int Y = 0;

        public int ScreenWidth
        {
            get { return screenWidth; }
            set { screenWidth = value; }
        }
        public int ScreenHeight
        {
            get { return screenHeight; }
            set { screenHeight = value; }
        }

        // the amount to offset the grid cell from the edges
        public int OffsetX
        {
            get { return offX; }
            set { offX = value; recomputeGrid = true; }
        }
        public int OffsetY
        {
            get { return offY; }
            set { offY = value; recomputeGrid = true; }
        }

        public int CellWidth
        {
            get { return width; }
            set { width = value; halfWidth = value / 2; recomputeGrid = true; }
        }
        public int CellHeight
        {
            get { return height; }
            set { height = value; halfHeight = value / 2; recomputeGrid = true; }
        }
        public int CellSpaceX
        {
            get { return spaceX; }
            set { spaceX = value; recomputeGrid = true; }
        }
        public int CellSpaceY
        {
            get { return spaceY; }
            set { spaceY = value; recomputeGrid = true; }
        }

        private int screenWidth = 0;
        private int screenHeight = 0;

        private int offX = 0;
        private int offY = 0;

        private int spaceX = 0;
        private int spaceY = 0;
        private int width = 1;
        private int height = 1;
        private int halfWidth = 0;
        private int halfHeight = 0;

        // snaps the point to the closesest cell center
        public void SnapTo(ref Point p)
        {
            p.X = SnapToX(p.X);
            p.Y = SnapToY(p.Y);
        }

        public void SnapToX(ref int x)
        {
            x = SnapToX(x);
        }

        public void SnapToY(ref int y)
        {
            y = SnapToY(y);
        }

        public int SnapToX(int x)
        {
            int index = ColIndex(x);

            return ColDistance(index) + halfWidth;
        }

        public int SnapToY(int y)
        {
            int index = RowIndex(y);
            return RowDistance(index) + halfHeight;
        }

        // gets the distance from the top of the grid (y) to the top of the ith row
        private int RowDistance(int i)
        {
            int constOffset = Y + offY + spaceY;
            return constOffset + (height + spaceY) * i;
        }

        // gets the distance from the left side of the grid (x) to the left side of the ith col
        private int ColDistance(int i)
        {
            int constOffset = X + offX + spaceX;
            return constOffset + (width + spaceX) * i;
        }

        // Gets the row index that the given y belongs to
        private int RowIndex(int y)
        {
            int constOffset = Y + offY + spaceY;

            int v = y - constOffset;

            return (int)Math.Floor((double)v / (height + spaceY));
        }

        // Gets the col index that the given x belongs to
        private int ColIndex(int x)
        {
            int constOffset = X + offX + spaceX;

            int v = x - constOffset;

            return (int)Math.Floor((double)v / (width + spaceX));
        }

        Rectangle[] cells = null;

        private bool recomputeGrid = true;
        private void ComputeGrid()
        {
            List<Rectangle> rects = new List<Rectangle>();

            int iX = ColIndex(0);
            int iY = RowIndex(0);

            List<int> rowDistances = new List<int>();
            int rowD = RowDistance(iY);
            while (rowD <= screenHeight)
            {
                rowDistances.Add(rowD);
                iY++;
                rowD = RowDistance(iY);
            }

            Rectangle r = new Rectangle(0, 0, width, height);
            int colD = ColDistance(iX);
            while (colD <= screenWidth)
            {
                r.X = colD;
                foreach (int i in rowDistances)
                {
                    r.Y = i;
                    rects.Add(r);
                }

                iX++;
                colD = ColDistance(iX);
            }
            
            cells = rects.ToArray();
        }

        private Pen cellPen = new Pen(Color.Gray);
        private Pen linePen = Pens.Gray;


        public void Draw(Graphics gfx)
        {
            cellPen.DashStyle = DashStyle.Dot;

            if (width < 5 || height < 5)
                return;

            if (recomputeGrid)
            {
                ComputeGrid();
                recomputeGrid = false;
            }

            gfx.DrawRectangles(cellPen, cells);
        }
    }
}
