﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace LevelEditor
{
    public partial class ImageSelectionDialog : DataSelectionDialog
    {
        public ImageSelectionDialog()
        {
            InitializeComponent();
        }

        protected override void SetPreview()
        {
            FileInfo info = new FileInfo(selectionFullPath);

            currImage = Bitmap.FromFile(selectionFullPath);

            sizeLabel.Text = Convert.ToString(currImage.Width) + " x " + Convert.ToString(currImage.Height);

            float kb = info.Length / 1024.0f;
            float mb = kb / 1024.0f;

            if (mb > 1.0f)
                dataSizeLabel.Text = Convert.ToString(mb) + " MB";
            else
                dataSizeLabel.Text = Convert.ToString(kb) + " KB";
        }

        protected override void ResetPreview() 
        {
            currImage = null;

            sizeLabel.Text = "0 x 0";
            dataSizeLabel.Text = "0 KB";
        }

        private void imagePanel_Paint(object sender, PaintEventArgs e)
        {
            Graphics gfx = imagePanel.CreateGraphics();
            gfx.Clear(Color.Transparent);

            if(currImage == null)
                return;

            float scaleW = (float)imagePanel.Width / currImage.Width;
            float scaleH = (float)imagePanel.Height / currImage.Height;
            float scale = Math.Min(Math.Min(scaleW, scaleH), 1.0f);

            float width = scale * currImage.Width;
            float height = scale * currImage.Height;

            float x = (imagePanel.Width / 2.0f) - (width / 2.0f);
            float y = (imagePanel.Height / 2.0f) - (height / 2.0f);

            gfx.DrawImage(currImage, x, y, width, height);
        }

        private Image currImage = null;
    }
}
