﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace LevelEditor
{
    public partial class ShapeSelectionDialog : DataSelectionDialog
    {
        public ShapeSelectionDialog()
        {
            InitializeComponent();
        }

        private void SetTransform()
        {
            if(activeShape != null)
            {
                float scaleX = (float)ShapeView.Width / bbox.Width;
                float scaleY = (float)ShapeView.Height / bbox.Height;
                float scale = Math.Min(scaleX, scaleY) / 2.0f;
                
                float w2 = ShapeView.Width / 2.0f;
                float h2 =  ShapeView.Height / 2.0f;

                float cx = (bbox.Width / 2.0f) * scale;
                float cy = (bbox.Height / 2.0f) * scale;

                Trans.Reset();

                Trans.Translate(w2, h2);
                Trans.Scale(scale, -scale);
            }
        }

        protected override void SetPreview()
        {
            try
            {
                activeShape = Shape.LoadShapeFromFile(selectionFullPath);
                bbox = activeShape.GetBoundingBox();

                SetTransform();

                Refresh();
            }
            catch (Shape.InvalidShapeFileException)
            {
                activeShape = null;
            }
        }

        protected override void ResetPreview()
        {
            activeShape = null;
        }

        private void ShapeView_SizeChanged(object sender, EventArgs e)
        {
            SetTransform();
        }

        private void BBoxCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            drawBBoxes = BBoxCheckBox.Checked;
            ShapeView.Refresh();
        }

        private void ShapeView_Paint(object sender, PaintEventArgs e)
        {
            if (activeShape != null)
            {
                Graphics gfx = ShapeView.CreateGraphics();
                gfx.Clear(Color.Black);

                gfx.MultiplyTransform(Trans);

                activeShape.Draw(gfx);

                if(drawBBoxes)
                    activeShape.DrawBoundingBoxes(gfx);
            }
        }

        private Shape activeShape = null;
        private RectangleF bbox;
        private bool drawBBoxes = false;

        private Matrix flipY = new Matrix(1.0f, 0.0f, 0.0f, -1.0f, 0.0f, 0.0f);
        private Matrix Trans = new Matrix();
    }
}
